<div align="center">

# Library of PAICORE 2.0

</div>

<p align="center">
    <a href="https://github.com/PAICookers/PAIlib/blob/master/pyproject.toml">
        <img src="https://img.shields.io/pypi/pyversions/paicorelib">
    </a>
    <a href="https://github.com/PAICookers/PAIlib/releases/tag/v0.0.10">
        <img src="https://img.shields.io/github/v/release/PAICookers/PAIlib?color=orange">
    </a>
    <a href="https://www.codefactor.io/repository/github/PAICookers/PAIlib">
      <img src="https://img.shields.io/codefactor/grade/github/PAICookers/PAIlib/master?color=red">
    </a>
    <a href="https://results.pre-commit.ci/latest/github/PAICookers/PAIlib/master">
	   <img src="https://results.pre-commit.ci/badge/github/PAICookers/PAIlib/master.svg" alt="pre-commit.ci status">
    </a>

</p>

This is the library of PAIBox & runtime.

术语对照表：[Table of Terms](docs/Table-of-Terms.md)
